package com.cabintechglobal.sampleratefix;

/**
 * This utility was used in development of SampleRateFix to experiment with the WavFile reader
 * and dump out the first part of the WAV data for manual inspection. It writes to stdout the
 * first 15,000 samples from channel 1 found in the input WAV file specified as the first argument.
 */

import java.io.File;
import java.io.IOException;

import com.wavefile.WavFile;
import com.wavefile.WavFileException;

public class DumpSamples {
	public static void main(String[] args)
	{
		try
		{
			// Open the wav file specified as the first argument
			WavFile wavFile = WavFile.openWavFile(new File(args[0]));

			// Display information about the wav file
			wavFile.display();

			// Get the number of audio channels in the wav file
			int numChannels = wavFile.getNumChannels();
			
			int cnt = 1;
			while (cnt < Integer.MAX_VALUE) { // Loop until end of data (exception from read code).
				try {
					double val = (double)wavFile.readSample();
					for (int chan=1;chan<numChannels;chan++) { // Discard all other channels
						val = (double)wavFile.readSample();
					}
					cnt++;
					if (cnt < 15000) {
						System.out.println(val);
					}
				}
				catch (WavFileException ex) {
					System.out.println("Read "+cnt+" samples.");
					wavFile.close();
					return;
				}
			}
		}
		catch (Exception e)
		{
			System.err.println(e);
		}
	}
	
}
